# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "OverviewRetrieveStatusResponse",
    "Translations",
    "TranslationsID",
    "TranslationsAm",
    "TranslationsAr",
    "TranslationsAz",
    "TranslationsBg",
    "TranslationsBn",
    "TranslationsCa",
    "TranslationsCs",
    "TranslationsDa",
    "TranslationsDe",
    "TranslationsEl",
    "TranslationsEn",
    "TranslationsEs",
    "TranslationsEt",
    "TranslationsFa",
    "TranslationsFi",
    "TranslationsFr",
    "TranslationsGu",
    "TranslationsHa",
    "TranslationsHe",
    "TranslationsHi",
    "TranslationsHr",
    "TranslationsHu",
    "TranslationsIt",
    "TranslationsJa",
    "TranslationsKa",
    "TranslationsKn",
    "TranslationsKo",
    "TranslationsLt",
    "TranslationsLv",
    "TranslationsMl",
    "TranslationsMr",
    "TranslationsMs",
    "TranslationsMy",
    "TranslationsNe",
    "TranslationsNl",
    "TranslationsNo",
    "TranslationsPa",
    "TranslationsPl",
    "TranslationsPt",
    "TranslationsRo",
    "TranslationsRu",
    "TranslationsSi",
    "TranslationsSk",
    "TranslationsSl",
    "TranslationsSr",
    "TranslationsSv",
    "TranslationsSw",
    "TranslationsTa",
    "TranslationsTe",
    "TranslationsTh",
    "TranslationsTl",
    "TranslationsTr",
    "TranslationsUk",
    "TranslationsUr",
    "TranslationsUz",
    "TranslationsVi",
    "TranslationsYo",
    "TranslationsZh",
]


class TranslationsID(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAm(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAz(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsBg(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsBn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsCa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsCs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsDa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsDe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsGu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsIt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsJa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsLt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsLv(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMy(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsRo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsRu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSk(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSv(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSw(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTh(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUk(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUz(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsVi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsYo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsZh(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class Translations(BaseModel):
    id: Optional[TranslationsID] = None

    am: Optional[TranslationsAm] = None

    ar: Optional[TranslationsAr] = None

    az: Optional[TranslationsAz] = None

    bg: Optional[TranslationsBg] = None

    bn: Optional[TranslationsBn] = None

    ca: Optional[TranslationsCa] = None

    cs: Optional[TranslationsCs] = None

    da: Optional[TranslationsDa] = None

    de: Optional[TranslationsDe] = None

    el: Optional[TranslationsEl] = None

    en: Optional[TranslationsEn] = None

    es: Optional[TranslationsEs] = None

    et: Optional[TranslationsEt] = None

    fa: Optional[TranslationsFa] = None

    fi: Optional[TranslationsFi] = None

    fr: Optional[TranslationsFr] = None

    gu: Optional[TranslationsGu] = None

    ha: Optional[TranslationsHa] = None

    he: Optional[TranslationsHe] = None

    hi: Optional[TranslationsHi] = None

    hr: Optional[TranslationsHr] = None

    hu: Optional[TranslationsHu] = None

    it: Optional[TranslationsIt] = None

    ja: Optional[TranslationsJa] = None

    ka: Optional[TranslationsKa] = None

    kn: Optional[TranslationsKn] = None

    ko: Optional[TranslationsKo] = None

    lt: Optional[TranslationsLt] = None

    lv: Optional[TranslationsLv] = None

    ml: Optional[TranslationsMl] = None

    mr: Optional[TranslationsMr] = None

    ms: Optional[TranslationsMs] = None

    my: Optional[TranslationsMy] = None

    ne: Optional[TranslationsNe] = None

    nl: Optional[TranslationsNl] = None

    no: Optional[TranslationsNo] = None

    pa: Optional[TranslationsPa] = None

    pl: Optional[TranslationsPl] = None

    pt: Optional[TranslationsPt] = None

    ro: Optional[TranslationsRo] = None

    ru: Optional[TranslationsRu] = None

    si: Optional[TranslationsSi] = None

    sk: Optional[TranslationsSk] = None

    sl: Optional[TranslationsSl] = None

    sr: Optional[TranslationsSr] = None

    sv: Optional[TranslationsSv] = None

    sw: Optional[TranslationsSw] = None

    ta: Optional[TranslationsTa] = None

    te: Optional[TranslationsTe] = None

    th: Optional[TranslationsTh] = None

    tl: Optional[TranslationsTl] = None

    tr: Optional[TranslationsTr] = None

    uk: Optional[TranslationsUk] = None

    ur: Optional[TranslationsUr] = None

    uz: Optional[TranslationsUz] = None

    vi: Optional[TranslationsVi] = None

    yo: Optional[TranslationsYo] = None

    zh: Optional[TranslationsZh] = None


class OverviewRetrieveStatusResponse(BaseModel):
    state: Literal["queued", "extracting", "generating", "done", "errored"]

    translations: Translations

    updated_at: float = FieldInfo(alias="updatedAt")
    """Milliseconds since UNIX epoch"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v2_search_params import V2SearchParams as V2SearchParams
from .v2_search_response import V2SearchResponse as V2SearchResponse
from .v2_list_top_response import V2ListTopResponse as V2ListTopResponse
from .v2_toggle_follow_response import V2ToggleFollowResponse as V2ToggleFollowResponse
from .v2_retrieve_by_id_response import V2RetrieveByIDResponse as V2RetrieveByIDResponse
from .v2_retrieve_by_name_response import V2RetrieveByNameResponse as V2RetrieveByNameResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .organizations import (
    OrganizationsResource,
    AsyncOrganizationsResource,
    OrganizationsResourceWithRawResponse,
    AsyncOrganizationsResourceWithRawResponse,
    OrganizationsResourceWithStreamingResponse,
    AsyncOrganizationsResourceWithStreamingResponse,
)

__all__ = [
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "OrganizationsResource",
    "AsyncOrganizationsResource",
    "OrganizationsResourceWithRawResponse",
    "AsyncOrganizationsResourceWithRawResponse",
    "OrganizationsResourceWithStreamingResponse",
    "AsyncOrganizationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.notifications.v4 import archive_list_params, archive_create_params
from ....types.notifications.v4.archive_list_response import ArchiveListResponse
from ....types.notifications.v4.archive_create_response import ArchiveCreateResponse

__all__ = ["ArchiveResource", "AsyncArchiveResource"]


class ArchiveResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ArchiveResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return ArchiveResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ArchiveResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return ArchiveResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ArchiveCreateResponse:
        """
        Given an array of IDs to mark as read, move them into the notification archive.
        Invalid notifications are ignored. By checking the returned count, invalid
        client-side state can be detected and corrected.

        Source file:
        `api-server/src/controllers/notifications/v4/archive-notifications.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/notifications/v4/archive",
            body=maybe_transform({"ids": ids}, archive_create_params.ArchiveCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ArchiveCreateResponse,
        )

    def list(
        self,
        *,
        before: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ArchiveListResponse:
        """
        The notification archive is paginated, requiring multiple calls to query long
        history.

        Source file:
        `api-server/src/controllers/notifications/v4/get-archived-notifications.controller.ts`

        Args:
          before: Decimal UNIX time in milliseconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/notifications/v4/archive",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"before": before}, archive_list_params.ArchiveListParams),
            ),
            cast_to=ArchiveListResponse,
        )


class AsyncArchiveResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncArchiveResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncArchiveResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncArchiveResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncArchiveResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ArchiveCreateResponse:
        """
        Given an array of IDs to mark as read, move them into the notification archive.
        Invalid notifications are ignored. By checking the returned count, invalid
        client-side state can be detected and corrected.

        Source file:
        `api-server/src/controllers/notifications/v4/archive-notifications.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/notifications/v4/archive",
            body=await async_maybe_transform({"ids": ids}, archive_create_params.ArchiveCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ArchiveCreateResponse,
        )

    async def list(
        self,
        *,
        before: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ArchiveListResponse:
        """
        The notification archive is paginated, requiring multiple calls to query long
        history.

        Source file:
        `api-server/src/controllers/notifications/v4/get-archived-notifications.controller.ts`

        Args:
          before: Decimal UNIX time in milliseconds

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/notifications/v4/archive",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"before": before}, archive_list_params.ArchiveListParams),
            ),
            cast_to=ArchiveListResponse,
        )


class ArchiveResourceWithRawResponse:
    def __init__(self, archive: ArchiveResource) -> None:
        self._archive = archive

        self.create = to_raw_response_wrapper(
            archive.create,
        )
        self.list = to_raw_response_wrapper(
            archive.list,
        )


class AsyncArchiveResourceWithRawResponse:
    def __init__(self, archive: AsyncArchiveResource) -> None:
        self._archive = archive

        self.create = async_to_raw_response_wrapper(
            archive.create,
        )
        self.list = async_to_raw_response_wrapper(
            archive.list,
        )


class ArchiveResourceWithStreamingResponse:
    def __init__(self, archive: ArchiveResource) -> None:
        self._archive = archive

        self.create = to_streamed_response_wrapper(
            archive.create,
        )
        self.list = to_streamed_response_wrapper(
            archive.list,
        )


class AsyncArchiveResourceWithStreamingResponse:
    def __init__(self, archive: AsyncArchiveResource) -> None:
        self._archive = archive

        self.create = async_to_streamed_response_wrapper(
            archive.create,
        )
        self.list = async_to_streamed_response_wrapper(
            archive.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .email import (
    EmailResource,
    AsyncEmailResource,
    EmailResourceWithRawResponse,
    AsyncEmailResourceWithRawResponse,
    EmailResourceWithStreamingResponse,
    AsyncEmailResourceWithStreamingResponse,
)
from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.users.preference_get_folders_preferences_response import PreferenceGetFoldersPreferencesResponse

__all__ = ["PreferencesResource", "AsyncPreferencesResource"]


class PreferencesResource(SyncAPIResource):
    @cached_property
    def email(self) -> EmailResource:
        return EmailResource(self._client)

    @cached_property
    def with_raw_response(self) -> PreferencesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return PreferencesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PreferencesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return PreferencesResourceWithStreamingResponse(self)

    def get_folders_preferences(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PreferenceGetFoldersPreferencesResponse:
        """
        Get folder preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/get-folders-preferences.controller.ts`
        """
        return self._get(
            "/v2/users/preferences/folders",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PreferenceGetFoldersPreferencesResponse,
        )


class AsyncPreferencesResource(AsyncAPIResource):
    @cached_property
    def email(self) -> AsyncEmailResource:
        return AsyncEmailResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPreferencesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPreferencesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPreferencesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncPreferencesResourceWithStreamingResponse(self)

    async def get_folders_preferences(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PreferenceGetFoldersPreferencesResponse:
        """
        Get folder preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/get-folders-preferences.controller.ts`
        """
        return await self._get(
            "/v2/users/preferences/folders",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PreferenceGetFoldersPreferencesResponse,
        )


class PreferencesResourceWithRawResponse:
    def __init__(self, preferences: PreferencesResource) -> None:
        self._preferences = preferences

        self.get_folders_preferences = to_raw_response_wrapper(
            preferences.get_folders_preferences,
        )

    @cached_property
    def email(self) -> EmailResourceWithRawResponse:
        return EmailResourceWithRawResponse(self._preferences.email)


class AsyncPreferencesResourceWithRawResponse:
    def __init__(self, preferences: AsyncPreferencesResource) -> None:
        self._preferences = preferences

        self.get_folders_preferences = async_to_raw_response_wrapper(
            preferences.get_folders_preferences,
        )

    @cached_property
    def email(self) -> AsyncEmailResourceWithRawResponse:
        return AsyncEmailResourceWithRawResponse(self._preferences.email)


class PreferencesResourceWithStreamingResponse:
    def __init__(self, preferences: PreferencesResource) -> None:
        self._preferences = preferences

        self.get_folders_preferences = to_streamed_response_wrapper(
            preferences.get_folders_preferences,
        )

    @cached_property
    def email(self) -> EmailResourceWithStreamingResponse:
        return EmailResourceWithStreamingResponse(self._preferences.email)


class AsyncPreferencesResourceWithStreamingResponse:
    def __init__(self, preferences: AsyncPreferencesResource) -> None:
        self._preferences = preferences

        self.get_folders_preferences = async_to_streamed_response_wrapper(
            preferences.get_folders_preferences,
        )

    @cached_property
    def email(self) -> AsyncEmailResourceWithStreamingResponse:
        return AsyncEmailResourceWithStreamingResponse(self._preferences.email)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["PaperFastSearchResponse", "PaperFastSearchResponseItem"]


class PaperFastSearchResponseItem(BaseModel):
    link: str

    paper_id: str = FieldInfo(alias="paperId")
    """An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)"""

    snippet: str

    title: str

    is_private: Optional[bool] = FieldInfo(alias="isPrivate", default=None)


PaperFastSearchResponse: TypeAlias = List[PaperFastSearchResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .topics import (
    TopicsResource,
    AsyncTopicsResource,
    TopicsResourceWithRawResponse,
    AsyncTopicsResourceWithRawResponse,
    TopicsResourceWithStreamingResponse,
    AsyncTopicsResourceWithStreamingResponse,
)
from ....._types import Body, Query, Headers, NotGiven, not_given
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .organizations import (
    OrganizationsResource,
    AsyncOrganizationsResource,
    OrganizationsResourceWithRawResponse,
    AsyncOrganizationsResourceWithRawResponse,
    OrganizationsResourceWithStreamingResponse,
    AsyncOrganizationsResourceWithStreamingResponse,
)
from ....._base_client import make_request_options
from .....types.users.v3.following_list_response import FollowingListResponse

__all__ = ["FollowingResource", "AsyncFollowingResource"]


class FollowingResource(SyncAPIResource):
    @cached_property
    def topics(self) -> TopicsResource:
        return TopicsResource(self._client)

    @cached_property
    def organizations(self) -> OrganizationsResource:
        return OrganizationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> FollowingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return FollowingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FollowingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return FollowingResourceWithStreamingResponse(self)

    def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FollowingListResponse:
        """
        List the users that the given user is following

        Source file:
        `api-server/src/controllers/users/v3/get-following-users.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/users/v3/{id}/following",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FollowingListResponse,
        )


class AsyncFollowingResource(AsyncAPIResource):
    @cached_property
    def topics(self) -> AsyncTopicsResource:
        return AsyncTopicsResource(self._client)

    @cached_property
    def organizations(self) -> AsyncOrganizationsResource:
        return AsyncOrganizationsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncFollowingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncFollowingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFollowingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncFollowingResourceWithStreamingResponse(self)

    async def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> FollowingListResponse:
        """
        List the users that the given user is following

        Source file:
        `api-server/src/controllers/users/v3/get-following-users.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/users/v3/{id}/following",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=FollowingListResponse,
        )


class FollowingResourceWithRawResponse:
    def __init__(self, following: FollowingResource) -> None:
        self._following = following

        self.list = to_raw_response_wrapper(
            following.list,
        )

    @cached_property
    def topics(self) -> TopicsResourceWithRawResponse:
        return TopicsResourceWithRawResponse(self._following.topics)

    @cached_property
    def organizations(self) -> OrganizationsResourceWithRawResponse:
        return OrganizationsResourceWithRawResponse(self._following.organizations)


class AsyncFollowingResourceWithRawResponse:
    def __init__(self, following: AsyncFollowingResource) -> None:
        self._following = following

        self.list = async_to_raw_response_wrapper(
            following.list,
        )

    @cached_property
    def topics(self) -> AsyncTopicsResourceWithRawResponse:
        return AsyncTopicsResourceWithRawResponse(self._following.topics)

    @cached_property
    def organizations(self) -> AsyncOrganizationsResourceWithRawResponse:
        return AsyncOrganizationsResourceWithRawResponse(self._following.organizations)


class FollowingResourceWithStreamingResponse:
    def __init__(self, following: FollowingResource) -> None:
        self._following = following

        self.list = to_streamed_response_wrapper(
            following.list,
        )

    @cached_property
    def topics(self) -> TopicsResourceWithStreamingResponse:
        return TopicsResourceWithStreamingResponse(self._following.topics)

    @cached_property
    def organizations(self) -> OrganizationsResourceWithStreamingResponse:
        return OrganizationsResourceWithStreamingResponse(self._following.organizations)


class AsyncFollowingResourceWithStreamingResponse:
    def __init__(self, following: AsyncFollowingResource) -> None:
        self._following = following

        self.list = async_to_streamed_response_wrapper(
            following.list,
        )

    @cached_property
    def topics(self) -> AsyncTopicsResourceWithStreamingResponse:
        return AsyncTopicsResourceWithStreamingResponse(self._following.topics)

    @cached_property
    def organizations(self) -> AsyncOrganizationsResourceWithStreamingResponse:
        return AsyncOrganizationsResourceWithStreamingResponse(self._following.organizations)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers import ingest_ingest_latest_params, ingest_ingest_version_params
from ...types.papers.ingest_ingest_latest_response import IngestIngestLatestResponse
from ...types.papers.ingest_ingest_version_response import IngestIngestVersionResponse

__all__ = ["IngestResource", "AsyncIngestResource"]


class IngestResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IngestResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return IngestResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IngestResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return IngestResourceWithStreamingResponse(self)

    def ingest_latest(
        self,
        upid: str,
        *,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestIngestLatestResponse:
        """
        Ingest latest paper version if it doesn't exist (deprecated, used by browser
        extension)

        Source file:
        `api-server/src/controllers/v2/papers/ingest-paper-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return self._get(
            f"/v2/papers/{upid}/ingest",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"prevent_tracking": prevent_tracking}, ingest_ingest_latest_params.IngestIngestLatestParams
                ),
            ),
            cast_to=IngestIngestLatestResponse,
        )

    def ingest_version(
        self,
        version_label: str,
        *,
        upid: str,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestIngestVersionResponse:
        """
        Ingest a paper version if it doesn't exist (deprecated, used by browser
        extension)

        Source file: `api-server/src/controllers/v2/papers/ingest-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_label:
            raise ValueError(f"Expected a non-empty value for `version_label` but received {version_label!r}")
        return self._get(
            f"/v2/papers/{upid}/ingest/versions/{version_label}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"prevent_tracking": prevent_tracking}, ingest_ingest_version_params.IngestIngestVersionParams
                ),
            ),
            cast_to=IngestIngestVersionResponse,
        )


class AsyncIngestResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIngestResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncIngestResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIngestResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncIngestResourceWithStreamingResponse(self)

    async def ingest_latest(
        self,
        upid: str,
        *,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestIngestLatestResponse:
        """
        Ingest latest paper version if it doesn't exist (deprecated, used by browser
        extension)

        Source file:
        `api-server/src/controllers/v2/papers/ingest-paper-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return await self._get(
            f"/v2/papers/{upid}/ingest",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"prevent_tracking": prevent_tracking}, ingest_ingest_latest_params.IngestIngestLatestParams
                ),
            ),
            cast_to=IngestIngestLatestResponse,
        )

    async def ingest_version(
        self,
        version_label: str,
        *,
        upid: str,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IngestIngestVersionResponse:
        """
        Ingest a paper version if it doesn't exist (deprecated, used by browser
        extension)

        Source file: `api-server/src/controllers/v2/papers/ingest-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_label:
            raise ValueError(f"Expected a non-empty value for `version_label` but received {version_label!r}")
        return await self._get(
            f"/v2/papers/{upid}/ingest/versions/{version_label}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"prevent_tracking": prevent_tracking}, ingest_ingest_version_params.IngestIngestVersionParams
                ),
            ),
            cast_to=IngestIngestVersionResponse,
        )


class IngestResourceWithRawResponse:
    def __init__(self, ingest: IngestResource) -> None:
        self._ingest = ingest

        self.ingest_latest = to_raw_response_wrapper(
            ingest.ingest_latest,
        )
        self.ingest_version = to_raw_response_wrapper(
            ingest.ingest_version,
        )


class AsyncIngestResourceWithRawResponse:
    def __init__(self, ingest: AsyncIngestResource) -> None:
        self._ingest = ingest

        self.ingest_latest = async_to_raw_response_wrapper(
            ingest.ingest_latest,
        )
        self.ingest_version = async_to_raw_response_wrapper(
            ingest.ingest_version,
        )


class IngestResourceWithStreamingResponse:
    def __init__(self, ingest: IngestResource) -> None:
        self._ingest = ingest

        self.ingest_latest = to_streamed_response_wrapper(
            ingest.ingest_latest,
        )
        self.ingest_version = to_streamed_response_wrapper(
            ingest.ingest_version,
        )


class AsyncIngestResourceWithStreamingResponse:
    def __init__(self, ingest: AsyncIngestResource) -> None:
        self._ingest = ingest

        self.ingest_latest = async_to_streamed_response_wrapper(
            ingest.ingest_latest,
        )
        self.ingest_version = async_to_streamed_response_wrapper(
            ingest.ingest_version,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .retool import (
    RetoolResource,
    AsyncRetoolResource,
    RetoolResourceWithRawResponse,
    AsyncRetoolResourceWithRawResponse,
    RetoolResourceWithStreamingResponse,
    AsyncRetoolResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "RetoolResource",
    "AsyncRetoolResource",
    "RetoolResourceWithRawResponse",
    "AsyncRetoolResourceWithRawResponse",
    "RetoolResourceWithStreamingResponse",
    "AsyncRetoolResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .seen_mark_seen_params import SeenMarkSeenParams as SeenMarkSeenParams
from .seen_get_seen_response import SeenGetSeenResponse as SeenGetSeenResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.papers.v3.legacy_retrieve_response import LegacyRetrieveResponse
from ....types.papers.v3.legacy_retrieve_comments_response import LegacyRetrieveCommentsResponse

__all__ = ["LegacyResource", "AsyncLegacyResource"]


class LegacyResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> LegacyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return LegacyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> LegacyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return LegacyResourceWithStreamingResponse(self)

    def retrieve(
        self,
        unresolved: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LegacyRetrieveResponse:
        """Retrieve paper version metadata and comments.

        Fetches from ArXiv if needed. This
        runs the old id resolution implementation, old fetching service, and old JSON
        format. Do not write new code with this please.

        Source file:
        `api-server/src/controllers/papers/v3/legacy/get-v2-paper-for-display.controller.ts`

        Args:
          unresolved: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not unresolved:
            raise ValueError(f"Expected a non-empty value for `unresolved` but received {unresolved!r}")
        return self._get(
            f"/papers/v3/legacy/{unresolved}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LegacyRetrieveResponse,
        )

    def retrieve_comments(
        self,
        group: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LegacyRetrieveCommentsResponse:
        """Retrieve paper group comments.

        Does not distinguish "paper group does not exist"
        from "there are no comments"

        Source file:
        `api-server/src/controllers/papers/v3/legacy/get-v2-comments.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group:
            raise ValueError(f"Expected a non-empty value for `group` but received {group!r}")
        return self._get(
            f"/papers/v3/legacy/{group}/comments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LegacyRetrieveCommentsResponse,
        )


class AsyncLegacyResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncLegacyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncLegacyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncLegacyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncLegacyResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        unresolved: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LegacyRetrieveResponse:
        """Retrieve paper version metadata and comments.

        Fetches from ArXiv if needed. This
        runs the old id resolution implementation, old fetching service, and old JSON
        format. Do not write new code with this please.

        Source file:
        `api-server/src/controllers/papers/v3/legacy/get-v2-paper-for-display.controller.ts`

        Args:
          unresolved: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not unresolved:
            raise ValueError(f"Expected a non-empty value for `unresolved` but received {unresolved!r}")
        return await self._get(
            f"/papers/v3/legacy/{unresolved}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LegacyRetrieveResponse,
        )

    async def retrieve_comments(
        self,
        group: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> LegacyRetrieveCommentsResponse:
        """Retrieve paper group comments.

        Does not distinguish "paper group does not exist"
        from "there are no comments"

        Source file:
        `api-server/src/controllers/papers/v3/legacy/get-v2-comments.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not group:
            raise ValueError(f"Expected a non-empty value for `group` but received {group!r}")
        return await self._get(
            f"/papers/v3/legacy/{group}/comments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LegacyRetrieveCommentsResponse,
        )


class LegacyResourceWithRawResponse:
    def __init__(self, legacy: LegacyResource) -> None:
        self._legacy = legacy

        self.retrieve = to_raw_response_wrapper(
            legacy.retrieve,
        )
        self.retrieve_comments = to_raw_response_wrapper(
            legacy.retrieve_comments,
        )


class AsyncLegacyResourceWithRawResponse:
    def __init__(self, legacy: AsyncLegacyResource) -> None:
        self._legacy = legacy

        self.retrieve = async_to_raw_response_wrapper(
            legacy.retrieve,
        )
        self.retrieve_comments = async_to_raw_response_wrapper(
            legacy.retrieve_comments,
        )


class LegacyResourceWithStreamingResponse:
    def __init__(self, legacy: LegacyResource) -> None:
        self._legacy = legacy

        self.retrieve = to_streamed_response_wrapper(
            legacy.retrieve,
        )
        self.retrieve_comments = to_streamed_response_wrapper(
            legacy.retrieve_comments,
        )


class AsyncLegacyResourceWithStreamingResponse:
    def __init__(self, legacy: AsyncLegacyResource) -> None:
        self._legacy = legacy

        self.retrieve = async_to_streamed_response_wrapper(
            legacy.retrieve,
        )
        self.retrieve_comments = async_to_streamed_response_wrapper(
            legacy.retrieve_comments,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v3.v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["FoldersResource", "AsyncFoldersResource"]


class FoldersResource(SyncAPIResource):
    @cached_property
    def v3(self) -> V3Resource:
        return V3Resource(self._client)

    @cached_property
    def with_raw_response(self) -> FoldersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return FoldersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> FoldersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return FoldersResourceWithStreamingResponse(self)


class AsyncFoldersResource(AsyncAPIResource):
    @cached_property
    def v3(self) -> AsyncV3Resource:
        return AsyncV3Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncFoldersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncFoldersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncFoldersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncFoldersResourceWithStreamingResponse(self)


class FoldersResourceWithRawResponse:
    def __init__(self, folders: FoldersResource) -> None:
        self._folders = folders

    @cached_property
    def v3(self) -> V3ResourceWithRawResponse:
        return V3ResourceWithRawResponse(self._folders.v3)


class AsyncFoldersResourceWithRawResponse:
    def __init__(self, folders: AsyncFoldersResource) -> None:
        self._folders = folders

    @cached_property
    def v3(self) -> AsyncV3ResourceWithRawResponse:
        return AsyncV3ResourceWithRawResponse(self._folders.v3)


class FoldersResourceWithStreamingResponse:
    def __init__(self, folders: FoldersResource) -> None:
        self._folders = folders

    @cached_property
    def v3(self) -> V3ResourceWithStreamingResponse:
        return V3ResourceWithStreamingResponse(self._folders.v3)


class AsyncFoldersResourceWithStreamingResponse:
    def __init__(self, folders: AsyncFoldersResource) -> None:
        self._folders = folders

    @cached_property
    def v3(self) -> AsyncV3ResourceWithStreamingResponse:
        return AsyncV3ResourceWithStreamingResponse(self._folders.v3)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3RetrieveGeoTrendsParams"]


class V3RetrieveGeoTrendsParams(TypedDict, total=False):
    collaboration_limit: Annotated[str, PropertyInfo(alias="collaborationLimit")]

    paper_limit: Annotated[str, PropertyInfo(alias="paperLimit")]

    past_months: Annotated[str, PropertyInfo(alias="pastMonths")]

    repo_limit: Annotated[str, PropertyInfo(alias="repoLimit")]

    top_countries: Annotated[str, PropertyInfo(alias="topCountries")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["V2GetURLMetadataResponse"]


class V2GetURLMetadataResponse(BaseModel):
    favicon: Optional[str] = None

    title: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1GenerateSpeechParams"]


class V1GenerateSpeechParams(TypedDict, total=False):
    paper_group_id: Required[Annotated[str, PropertyInfo(alias="paperGroupId")]]
    """Paper group ID for caching"""

    text: Required[str]
    """Text to convert to speech"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .legacy import (
    LegacyResource,
    AsyncLegacyResource,
    LegacyResourceWithRawResponse,
    AsyncLegacyResourceWithRawResponse,
    LegacyResourceWithStreamingResponse,
    AsyncLegacyResourceWithStreamingResponse,
)
from .overview import (
    OverviewResource,
    AsyncOverviewResource,
    OverviewResourceWithRawResponse,
    AsyncOverviewResourceWithRawResponse,
    OverviewResourceWithStreamingResponse,
    AsyncOverviewResourceWithStreamingResponse,
)
from .x_mentions import (
    XMentionsResource,
    AsyncXMentionsResource,
    XMentionsResourceWithRawResponse,
    AsyncXMentionsResourceWithRawResponse,
    XMentionsResourceWithStreamingResponse,
    AsyncXMentionsResourceWithStreamingResponse,
)
from .implementations import (
    ImplementationsResource,
    AsyncImplementationsResource,
    ImplementationsResourceWithRawResponse,
    AsyncImplementationsResourceWithRawResponse,
    ImplementationsResourceWithStreamingResponse,
    AsyncImplementationsResourceWithStreamingResponse,
)

__all__ = [
    "LegacyResource",
    "AsyncLegacyResource",
    "LegacyResourceWithRawResponse",
    "AsyncLegacyResourceWithRawResponse",
    "LegacyResourceWithStreamingResponse",
    "AsyncLegacyResourceWithStreamingResponse",
    "OverviewResource",
    "AsyncOverviewResource",
    "OverviewResourceWithRawResponse",
    "AsyncOverviewResourceWithRawResponse",
    "OverviewResourceWithStreamingResponse",
    "AsyncOverviewResourceWithStreamingResponse",
    "ImplementationsResource",
    "AsyncImplementationsResource",
    "ImplementationsResourceWithRawResponse",
    "AsyncImplementationsResourceWithRawResponse",
    "ImplementationsResourceWithStreamingResponse",
    "AsyncImplementationsResourceWithStreamingResponse",
    "XMentionsResource",
    "AsyncXMentionsResource",
    "XMentionsResourceWithRawResponse",
    "AsyncXMentionsResourceWithRawResponse",
    "XMentionsResourceWithStreamingResponse",
    "AsyncXMentionsResourceWithStreamingResponse",
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ....._types import Body, Query, Headers, NotGiven, not_given
from ....._utils import maybe_transform, async_maybe_transform
from ....._compat import cached_property
from ....._resource import SyncAPIResource, AsyncAPIResource
from ....._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ....._base_client import make_request_options
from .....types.users.v3.following import organization_toggle_params
from .....types.users.v3.following.organization_list_response import OrganizationListResponse
from .....types.users.v3.following.organization_toggle_response import OrganizationToggleResponse

__all__ = ["OrganizationsResource", "AsyncOrganizationsResource"]


class OrganizationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrganizationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return OrganizationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrganizationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return OrganizationsResourceWithStreamingResponse(self)

    def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrganizationListResponse:
        """
        List the organizations followed by a user

        Source file:
        `api-server/src/controllers/users/v3/get-following-organizations.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/users/v3/{id}/following/organizations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationListResponse,
        )

    def toggle(
        self,
        id: str,
        *,
        organization: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrganizationToggleResponse:
        """
        Toggle following an organization for the current user

        Source file:
        `api-server/src/controllers/users/v3/toggle-following-organization.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/users/v3/{id}/following/organizations/toggle",
            body=maybe_transform({"organization": organization}, organization_toggle_params.OrganizationToggleParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationToggleResponse,
        )


class AsyncOrganizationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrganizationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrganizationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrganizationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncOrganizationsResourceWithStreamingResponse(self)

    async def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrganizationListResponse:
        """
        List the organizations followed by a user

        Source file:
        `api-server/src/controllers/users/v3/get-following-organizations.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/users/v3/{id}/following/organizations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationListResponse,
        )

    async def toggle(
        self,
        id: str,
        *,
        organization: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrganizationToggleResponse:
        """
        Toggle following an organization for the current user

        Source file:
        `api-server/src/controllers/users/v3/toggle-following-organization.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/users/v3/{id}/following/organizations/toggle",
            body=await async_maybe_transform(
                {"organization": organization}, organization_toggle_params.OrganizationToggleParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OrganizationToggleResponse,
        )


class OrganizationsResourceWithRawResponse:
    def __init__(self, organizations: OrganizationsResource) -> None:
        self._organizations = organizations

        self.list = to_raw_response_wrapper(
            organizations.list,
        )
        self.toggle = to_raw_response_wrapper(
            organizations.toggle,
        )


class AsyncOrganizationsResourceWithRawResponse:
    def __init__(self, organizations: AsyncOrganizationsResource) -> None:
        self._organizations = organizations

        self.list = async_to_raw_response_wrapper(
            organizations.list,
        )
        self.toggle = async_to_raw_response_wrapper(
            organizations.toggle,
        )


class OrganizationsResourceWithStreamingResponse:
    def __init__(self, organizations: OrganizationsResource) -> None:
        self._organizations = organizations

        self.list = to_streamed_response_wrapper(
            organizations.list,
        )
        self.toggle = to_streamed_response_wrapper(
            organizations.toggle,
        )


class AsyncOrganizationsResourceWithStreamingResponse:
    def __init__(self, organizations: AsyncOrganizationsResource) -> None:
        self._organizations = organizations

        self.list = async_to_streamed_response_wrapper(
            organizations.list,
        )
        self.toggle = async_to_streamed_response_wrapper(
            organizations.toggle,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.users.v3 import SemanticScholarLinkResponse, SemanticScholarScrapeResponse

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSemanticScholar:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_link(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            semantic_scholar = client.users.v3.semantic_scholar.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_link(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.users.v3.semantic_scholar.with_raw_response.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        semantic_scholar = response.parse()
        assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_link(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.users.v3.semantic_scholar.with_streaming_response.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                semantic_scholar = response.parse()
                assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_link(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                client.users.v3.semantic_scholar.with_raw_response.link(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_scrape(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            semantic_scholar = client.users.v3.semantic_scholar.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_scrape(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.users.v3.semantic_scholar.with_raw_response.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        semantic_scholar = response.parse()
        assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_scrape(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.users.v3.semantic_scholar.with_streaming_response.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                semantic_scholar = response.parse()
                assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_scrape(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                client.users.v3.semantic_scholar.with_raw_response.scrape(
                    "",
                )


class TestAsyncSemanticScholar:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_link(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            semantic_scholar = await async_client.users.v3.semantic_scholar.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_link(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.users.v3.semantic_scholar.with_raw_response.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        semantic_scholar = await response.parse()
        assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_link(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.users.v3.semantic_scholar.with_streaming_response.link(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                semantic_scholar = await response.parse()
                assert_matches_type(SemanticScholarLinkResponse, semantic_scholar, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_link(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                await async_client.users.v3.semantic_scholar.with_raw_response.link(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_scrape(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            semantic_scholar = await async_client.users.v3.semantic_scholar.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_scrape(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.users.v3.semantic_scholar.with_raw_response.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        semantic_scholar = await response.parse()
        assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_scrape(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.users.v3.semantic_scholar.with_streaming_response.scrape(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                semantic_scholar = await response.parse()
                assert_matches_type(SemanticScholarScrapeResponse, semantic_scholar, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_scrape(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                await async_client.users.v3.semantic_scholar.with_raw_response.scrape(
                    "",
                )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["V3CommentParams"]


class V3CommentParams(TypedDict, total=False):
    tag: Required[Literal["anonymous", "general", "personal", "research", "resources"]]

    body: Optional[str]

    parent: Optional[str]

    title: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3ImplementationResponse", "Implementation"]


class Implementation(BaseModel):
    id: str

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    type: Literal["github", "marimo"]

    url: str


class V3ImplementationResponse(BaseModel):
    implementation: Implementation



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.google_scholar import v1_connect_params, v1_set_email_params, v1_verify_email_params
from ...types.google_scholar.v1_sync_response import V1SyncResponse
from ...types.google_scholar.v1_resync_response import V1ResyncResponse
from ...types.google_scholar.v1_connect_response import V1ConnectResponse
from ...types.google_scholar.v1_get_report_response import V1GetReportResponse
from ...types.google_scholar.v1_get_status_response import V1GetStatusResponse
from ...types.google_scholar.v1_verify_email_response import V1VerifyEmailResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def connect(
        self,
        *,
        google_scholar_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ConnectResponse:
        """
        Start connecting Google Scholar profile to user account, or replace a pending
        connection with a different profile

        Source file:
        `api-server/src/controllers/google-scholar/v1/connect.controller.ts`

        Args:
          google_scholar_id: Google Scholar ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/google-scholar/v1",
            body=maybe_transform({"google_scholar_id": google_scholar_id}, v1_connect_params.V1ConnectParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ConnectResponse,
        )

    def delete_connection(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove Google Scholar ID and queued papers from a user

        Source file: `api-server/src/controllers/google-scholar/v1/delete.controller.ts`
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            "/google-scholar/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_report(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetReportResponse:
        """
        Get a full report of a user's Google Scholar sync (including lists of papers)

        Source file: `api-server/src/controllers/google-scholar/v1/report.controller.ts`
        """
        return self._get(
            "/google-scholar/v1/report",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetReportResponse,
        )

    def get_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetStatusResponse:
        """
        Get status of user's Google Scholar sync

        Source file: `api-server/src/controllers/google-scholar/v1/status.controller.ts`
        """
        return self._get(
            "/google-scholar/v1/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetStatusResponse,
        )

    def resync(
        self,
        mode: Literal["all", "new"],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ResyncResponse:
        """
        Start a new Google Scholar sync for this user

        Source file: `api-server/src/controllers/google-scholar/v1/resync.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mode:
            raise ValueError(f"Expected a non-empty value for `mode` but received {mode!r}")
        return self._post(
            f"/google-scholar/v1/resync/{mode}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ResyncResponse,
        )

    def set_email(
        self,
        *,
        local_part: str,
        verify_account_email: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Set the local-part of a user's Google Scholar institutional email and send a
        verification email to that address

        Source file:
        `api-server/src/controllers/google-scholar/v1/set-email.controller.ts`

        Args:
          local_part: Institutional email local-part

          verify_account_email: Send verification code to the user's primary email instead of the institutional
              email. Admin only.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._put(
            "/google-scholar/v1/email",
            body=maybe_transform(
                {
                    "local_part": local_part,
                    "verify_account_email": verify_account_email,
                },
                v1_set_email_params.V1SetEmailParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def sync(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1SyncResponse:
        """
        Make some progress syncing a user's Google Scholar papers

        Source file: `api-server/src/controllers/google-scholar/v1/sync.controller.ts`
        """
        return self._post(
            "/google-scholar/v1/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1SyncResponse,
        )

    def verify_email(
        self,
        *,
        code: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1VerifyEmailResponse:
        """
        Verify a user's Google Scholar email by entering the code sent to that email

        Source file: `api-server/src/controllers/google-scholar/v1/verify.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/google-scholar/v1/verify",
            body=maybe_transform({"code": code}, v1_verify_email_params.V1VerifyEmailParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1VerifyEmailResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def connect(
        self,
        *,
        google_scholar_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ConnectResponse:
        """
        Start connecting Google Scholar profile to user account, or replace a pending
        connection with a different profile

        Source file:
        `api-server/src/controllers/google-scholar/v1/connect.controller.ts`

        Args:
          google_scholar_id: Google Scholar ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/google-scholar/v1",
            body=await async_maybe_transform(
                {"google_scholar_id": google_scholar_id}, v1_connect_params.V1ConnectParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ConnectResponse,
        )

    async def delete_connection(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove Google Scholar ID and queued papers from a user

        Source file: `api-server/src/controllers/google-scholar/v1/delete.controller.ts`
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            "/google-scholar/v1",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_report(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetReportResponse:
        """
        Get a full report of a user's Google Scholar sync (including lists of papers)

        Source file: `api-server/src/controllers/google-scholar/v1/report.controller.ts`
        """
        return await self._get(
            "/google-scholar/v1/report",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetReportResponse,
        )

    async def get_status(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetStatusResponse:
        """
        Get status of user's Google Scholar sync

        Source file: `api-server/src/controllers/google-scholar/v1/status.controller.ts`
        """
        return await self._get(
            "/google-scholar/v1/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetStatusResponse,
        )

    async def resync(
        self,
        mode: Literal["all", "new"],
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ResyncResponse:
        """
        Start a new Google Scholar sync for this user

        Source file: `api-server/src/controllers/google-scholar/v1/resync.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not mode:
            raise ValueError(f"Expected a non-empty value for `mode` but received {mode!r}")
        return await self._post(
            f"/google-scholar/v1/resync/{mode}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1ResyncResponse,
        )

    async def set_email(
        self,
        *,
        local_part: str,
        verify_account_email: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Set the local-part of a user's Google Scholar institutional email and send a
        verification email to that address

        Source file:
        `api-server/src/controllers/google-scholar/v1/set-email.controller.ts`

        Args:
          local_part: Institutional email local-part

          verify_account_email: Send verification code to the user's primary email instead of the institutional
              email. Admin only.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._put(
            "/google-scholar/v1/email",
            body=await async_maybe_transform(
                {
                    "local_part": local_part,
                    "verify_account_email": verify_account_email,
                },
                v1_set_email_params.V1SetEmailParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def sync(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1SyncResponse:
        """
        Make some progress syncing a user's Google Scholar papers

        Source file: `api-server/src/controllers/google-scholar/v1/sync.controller.ts`
        """
        return await self._post(
            "/google-scholar/v1/sync",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1SyncResponse,
        )

    async def verify_email(
        self,
        *,
        code: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1VerifyEmailResponse:
        """
        Verify a user's Google Scholar email by entering the code sent to that email

        Source file: `api-server/src/controllers/google-scholar/v1/verify.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/google-scholar/v1/verify",
            body=await async_maybe_transform({"code": code}, v1_verify_email_params.V1VerifyEmailParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1VerifyEmailResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.connect = to_raw_response_wrapper(
            v1.connect,
        )
        self.delete_connection = to_raw_response_wrapper(
            v1.delete_connection,
        )
        self.get_report = to_raw_response_wrapper(
            v1.get_report,
        )
        self.get_status = to_raw_response_wrapper(
            v1.get_status,
        )
        self.resync = to_raw_response_wrapper(
            v1.resync,
        )
        self.set_email = to_raw_response_wrapper(
            v1.set_email,
        )
        self.sync = to_raw_response_wrapper(
            v1.sync,
        )
        self.verify_email = to_raw_response_wrapper(
            v1.verify_email,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.connect = async_to_raw_response_wrapper(
            v1.connect,
        )
        self.delete_connection = async_to_raw_response_wrapper(
            v1.delete_connection,
        )
        self.get_report = async_to_raw_response_wrapper(
            v1.get_report,
        )
        self.get_status = async_to_raw_response_wrapper(
            v1.get_status,
        )
        self.resync = async_to_raw_response_wrapper(
            v1.resync,
        )
        self.set_email = async_to_raw_response_wrapper(
            v1.set_email,
        )
        self.sync = async_to_raw_response_wrapper(
            v1.sync,
        )
        self.verify_email = async_to_raw_response_wrapper(
            v1.verify_email,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.connect = to_streamed_response_wrapper(
            v1.connect,
        )
        self.delete_connection = to_streamed_response_wrapper(
            v1.delete_connection,
        )
        self.get_report = to_streamed_response_wrapper(
            v1.get_report,
        )
        self.get_status = to_streamed_response_wrapper(
            v1.get_status,
        )
        self.resync = to_streamed_response_wrapper(
            v1.resync,
        )
        self.set_email = to_streamed_response_wrapper(
            v1.set_email,
        )
        self.sync = to_streamed_response_wrapper(
            v1.sync,
        )
        self.verify_email = to_streamed_response_wrapper(
            v1.verify_email,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.connect = async_to_streamed_response_wrapper(
            v1.connect,
        )
        self.delete_connection = async_to_streamed_response_wrapper(
            v1.delete_connection,
        )
        self.get_report = async_to_streamed_response_wrapper(
            v1.get_report,
        )
        self.get_status = async_to_streamed_response_wrapper(
            v1.get_status,
        )
        self.resync = async_to_streamed_response_wrapper(
            v1.resync,
        )
        self.set_email = async_to_streamed_response_wrapper(
            v1.set_email,
        )
        self.sync = async_to_streamed_response_wrapper(
            v1.sync,
        )
        self.verify_email = async_to_streamed_response_wrapper(
            v1.verify_email,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.comments.v2 import (
    ModeratorToggleFlagsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestModerator:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_feedback(self, client: AlphaxivCat) -> None:
        moderator = client.comments.v2.moderator.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        )
        assert moderator is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send_feedback(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.moderator.with_raw_response.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        moderator = response.parse()
        assert moderator is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send_feedback(self, client: AlphaxivCat) -> None:
        with client.comments.v2.moderator.with_streaming_response.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            moderator = response.parse()
            assert moderator is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_send_feedback(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.moderator.with_raw_response.send_feedback(
                comment="",
                message="message",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_flags(self, client: AlphaxivCat) -> None:
        moderator = client.comments.v2.moderator.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_flags_with_all_params(self, client: AlphaxivCat) -> None:
        moderator = client.comments.v2.moderator.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            addressed=True,
            closed=True,
            flag_addressed=True,
        )
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle_flags(self, client: AlphaxivCat) -> None:
        response = client.comments.v2.moderator.with_raw_response.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        moderator = response.parse()
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle_flags(self, client: AlphaxivCat) -> None:
        with client.comments.v2.moderator.with_streaming_response.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            moderator = response.parse()
            assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle_flags(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            client.comments.v2.moderator.with_raw_response.toggle_flags(
                comment="",
            )


class TestAsyncModerator:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_feedback(self, async_client: AsyncAlphaxivCat) -> None:
        moderator = await async_client.comments.v2.moderator.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        )
        assert moderator is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send_feedback(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.moderator.with_raw_response.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        moderator = await response.parse()
        assert moderator is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send_feedback(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.moderator.with_streaming_response.send_feedback(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            moderator = await response.parse()
            assert moderator is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_send_feedback(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.moderator.with_raw_response.send_feedback(
                comment="",
                message="message",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_flags(self, async_client: AsyncAlphaxivCat) -> None:
        moderator = await async_client.comments.v2.moderator.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_flags_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        moderator = await async_client.comments.v2.moderator.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            addressed=True,
            closed=True,
            flag_addressed=True,
        )
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle_flags(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.comments.v2.moderator.with_raw_response.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        moderator = await response.parse()
        assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle_flags(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.comments.v2.moderator.with_streaming_response.toggle_flags(
            comment="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            moderator = await response.parse()
            assert_matches_type(ModeratorToggleFlagsResponse, moderator, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle_flags(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `comment` but received ''"):
            await async_client.comments.v2.moderator.with_raw_response.toggle_flags(
                comment="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ...._models import BaseModel

__all__ = ["EmailUpdateResponse", "Data"]


class Data(BaseModel):
    success: bool


class EmailUpdateResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1RevokeResponse"]


class V1RevokeResponse(BaseModel):
    id: str

    label: str

    last_used_at: Optional[str] = FieldInfo(alias="lastUsedAt", default=None)

    prefix: str

    revoked_at: Optional[str] = FieldInfo(alias="revokedAt", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ...._models import BaseModel

__all__ = ["CitationGetGraphResponse", "Graph"]


class Graph(BaseModel):
    citations: float

    year: float


class CitationGetGraphResponse(BaseModel):
    graph: List[Graph]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "OverviewRetrieveResponse",
    "Citation",
    "Summary",
    "AITooltips",
    "OverviewSectionTitles",
    "SummarySectionTitles",
]


class Citation(BaseModel):
    alphaxiv_link: Optional[str] = FieldInfo(alias="alphaxivLink", default=None)

    full_citation: str = FieldInfo(alias="fullCitation")

    justification: str

    title: str


class Summary(BaseModel):
    key_insights: List[str] = FieldInfo(alias="keyInsights")

    original_problem: List[str] = FieldInfo(alias="originalProblem")

    results: List[str]

    solution: List[str]

    summary: str


class AITooltips(BaseModel):
    ai_generated_content: str = FieldInfo(alias="aiGeneratedContent")


class OverviewSectionTitles(BaseModel):
    relevant_citations: str = FieldInfo(alias="relevantCitations")

    table_of_contents: str = FieldInfo(alias="tableOfContents")


class SummarySectionTitles(BaseModel):
    abstract: str

    method: str

    problem: str

    results: str

    summary: str

    takeaways: str


class OverviewRetrieveResponse(BaseModel):
    abstract: str

    citations: List[Citation]

    intermediate_report: Optional[str] = FieldInfo(alias="intermediateReport", default=None)

    overview: str

    summary: Summary

    title: str

    ai_tooltips: Optional[AITooltips] = FieldInfo(alias="aiTooltips", default=None)

    overview_section_titles: Optional[OverviewSectionTitles] = FieldInfo(alias="overviewSectionTitles", default=None)

    summary_section_titles: Optional[SummarySectionTitles] = FieldInfo(alias="summarySectionTitles", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["EmailGetResponse", "Data"]


class Data(BaseModel):
    bounced: bool

    direct_notifications: bool = FieldInfo(alias="directNotifications")

    relevant_activity: bool = FieldInfo(alias="relevantActivity")


class EmailGetResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers.v3 import (
    ImplementationListResponse,
    ImplementationCreateResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestImplementations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: AlphaxivCat) -> None:
        implementation = client.papers.v3.implementations.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        )
        assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.implementations.with_raw_response.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = response.parse()
        assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: AlphaxivCat) -> None:
        with client.papers.v3.implementations.with_streaming_response.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = response.parse()
            assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_create(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.implementations.with_raw_response.create(
                paper_group_id="",
                implementation_type="alphaxiv",
                url="https://example.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: AlphaxivCat) -> None:
        implementation = client.papers.v3.implementations.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ImplementationListResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.implementations.with_raw_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = response.parse()
        assert_matches_type(ImplementationListResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: AlphaxivCat) -> None:
        with client.papers.v3.implementations.with_streaming_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = response.parse()
            assert_matches_type(ImplementationListResponse, implementation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_list(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.implementations.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: AlphaxivCat) -> None:
        implementation = client.papers.v3.implementations.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        )
        assert implementation is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.implementations.with_raw_response.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = response.parse()
        assert implementation is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: AlphaxivCat) -> None:
        with client.papers.v3.implementations.with_streaming_response.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = response.parse()
            assert implementation is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.implementations.with_raw_response.delete(
                implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                paper_group_id="",
                type="alphaxiv",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `implementation_id` but received ''"):
            client.papers.v3.implementations.with_raw_response.delete(
                implementation_id="",
                paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                type="alphaxiv",
            )


class TestAsyncImplementations:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAlphaxivCat) -> None:
        implementation = await async_client.papers.v3.implementations.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        )
        assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.implementations.with_raw_response.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = await response.parse()
        assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.implementations.with_streaming_response.create(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            implementation_type="alphaxiv",
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = await response.parse()
            assert_matches_type(ImplementationCreateResponse, implementation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.implementations.with_raw_response.create(
                paper_group_id="",
                implementation_type="alphaxiv",
                url="https://example.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAlphaxivCat) -> None:
        implementation = await async_client.papers.v3.implementations.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ImplementationListResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.implementations.with_raw_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = await response.parse()
        assert_matches_type(ImplementationListResponse, implementation, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.implementations.with_streaming_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = await response.parse()
            assert_matches_type(ImplementationListResponse, implementation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.implementations.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncAlphaxivCat) -> None:
        implementation = await async_client.papers.v3.implementations.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        )
        assert implementation is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.implementations.with_raw_response.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        implementation = await response.parse()
        assert implementation is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.implementations.with_streaming_response.delete(
            implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            type="alphaxiv",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            implementation = await response.parse()
            assert implementation is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.implementations.with_raw_response.delete(
                implementation_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                paper_group_id="",
                type="alphaxiv",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `implementation_id` but received ''"):
            await async_client.papers.v3.implementations.with_raw_response.delete(
                implementation_id="",
                paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                type="alphaxiv",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmailCaptureBouncedEmailsParams"]


class EmailCaptureBouncedEmailsParams(TypedDict, total=False):
    message: Required[Annotated[str, PropertyInfo(alias="Message")]]
    """Stringified JSON message containing bounce/complaint data"""

    type: Required[Annotated[str, PropertyInfo(alias="Type")]]
    """SNS notification type"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["VersionRequestAIOverviewParams"]


class VersionRequestAIOverviewParams(TypedDict, total=False):
    upid: Required[str]

    preferred_language: Annotated[
        Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        PropertyInfo(alias="preferredLanguage"),
    ]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v3_create_params import V3CreateParams as V3CreateParams
from .v3_list_response import V3ListResponse as V3ListResponse
from .v3_create_response import V3CreateResponse as V3CreateResponse
from .v3_add_papers_params import V3AddPapersParams as V3AddPapersParams
from .v3_move_papers_params import V3MovePapersParams as V3MovePapersParams
from .v3_update_name_params import V3UpdateNameParams as V3UpdateNameParams
from .v3_add_papers_response import V3AddPapersResponse as V3AddPapersResponse
from .v3_move_papers_response import V3MovePapersResponse as V3MovePapersResponse
from .v3_remove_papers_params import V3RemovePapersParams as V3RemovePapersParams
from .v3_update_parent_params import V3UpdateParentParams as V3UpdateParentParams
from .v3_toggle_sharing_params import V3ToggleSharingParams as V3ToggleSharingParams
from .v3_toggle_sharing_response import V3ToggleSharingResponse as V3ToggleSharingResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["AssistantUploadFileResponse", "Data"]


class Data(BaseModel):
    id: str

    content_type: str

    filename: str

    size: float

    url: str


class AssistantUploadFileResponse(BaseModel):
    data: Data
